@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "with-editor" "3.4.9"
+(define-package "with-editor" "20251101.2100"
   "Use the Emacsclient as $EDITOR."
   '((emacs  "26.1")
     (compat "30.1"))
   :url "https://github.com/magit/with-editor"
-  :commit "64211dcb815f2533ac3d2a7e56ff36ae804d8338"
-  :revdesc "v3.4.9-0-g64211dcb815f"
+  :commit "dbc694406c2fd8e9d3e6ffbc4f8aff4e8c28029f"
+  :revdesc "dbc694406c2f"
   :keywords '("processes" "terminals")
   :authors '(("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev")))
